@@ -17,11 +17,11 @@ def test_info_fixture(example_info):
     assert example_info["Angle"] == 69.09
     
 
-def test_data_fixture(load_example_data):
-    """Testing whether conftest.py fixture is working as expected."""
-    expectedChOn = [2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 17]
-    testTrue = load_example_data["On Channels"] == expectedChOn
-    errStr = (f"Header loaded incorrectly. Expected on channels are "
-              f"{expectedChOn}, but got {load_example_data['On Channels']} "
-              "instead.")
-    assert testTrue, errStr
\ No newline at end of file
+# def test_data_fixture(load_example_data):
+#     """Testing whether conftest.py fixture is working as expected."""
+#     expectedChOn = [2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 17]
+#     testTrue = load_example_data["On Channels"] == expectedChOn
+#     errStr = (f"Header loaded incorrectly. Expected on channels are "
+#               f"{expectedChOn}, but got {load_example_data['On Channels']} "
+#               "instead.")
+#     assert testTrue, errStr
\ No newline at end of file
